pub enum AttrIvarName {
Unspecified,
Empty,
Name(rbs_constant_id_t),
}Expand description
Instance variable name specification for attributes.
Variants
Unspecified
The attribute has inferred instance variable (nil)
Empty
The attribute has no instance variable (false)
Name(rbs_constant_id_t)
The attribute has instance variable with the given name
Implementations
Sourceimpl AttrIvarName
impl AttrIvarName
Sourcepub fn from_raw(raw: rbs_attr_ivar_name_t) -> Self
pub fn from_raw(raw: rbs_attr_ivar_name_t) -> Self
Converts the raw C struct to the Rust enum.